def save_int(path: str,data: int,mode: str ="w") -> bool:

    """Writes data to a file.

    Args:

        path (str): The path of the file.

        data (str): The data to be written.

        mode (str, optional): The file opening mode. Defaults to "w" (write mode).

    Returns:

        bool: True if the write operation is successful, False otherwise.

    """

    with open(path, mode) as f:

        f.write(str(data))

        return True

def load_int(path: str) -> int:

    """Reads the contents of a file.

    Args:

        path (str): The path of the file.

    Returns:

        int: Integer stored in file.

    """

    with open(path, "r") as f:

        return int(f.read())

        

def save_list(path: str,data: list,mode: str='w') -> bool:

    """Writes data to a file.

    Args:

        path (str): The path of the file.

        data (str): The data to be written.

        mode (str, optional): The file opening mode. Defaults to "w" (write mode).

    Returns:

        bool: True if the write operation is successful, False otherwise.

    """

    with open(path,mode) as f:

        for entry in data:

            f.write(str(entry) + '\n')

        return True

def load_list(path: str) -> list:

    """Reads the contents of a file.

    and return a list of content

    Args:

        path (str): The path of the file.

    Returns:

        int: Integer stored in file.

    """

    data = []

    with open(path, "r") as f:

        for text in f.readlines():

            text = text[0:-1]

            if text == str(True) or text == str(False):

                if text == str(True):

                    data.append(True)

                else:

                    data.append(False)

            elif text.startswith('[') and text.endswith(']'):

               data.append(text)

            elif text.startswith('(') and text.endswith(')'):

                data.append(text)

            elif text.startswith('{') and text.endswith('}'):

                data.append(text)

            elif not text.isalpha():

                text = float(text)

                data.append(text)

            else:

                data.append(text)

    return data



from setuptools import setup

setup(
    name='pyfilehandling',
    version='1.1.1',
    description='A Python package for file manipulation operations.',
    long_description='pyfilehandling is a Python package that provides functions and classes for handling file operations, including creating files and directories, reading and writing data, and more.',
    long_description_content_type='text/markdown',
    author='JeelDobariya',
    author_email='dobariyaj34@gmail.com',
    url='https://github.com/JeelDobariya38/pyfilehandling',
    packages=['pyfilehandling'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords='file handling manipulation',
    project_urls={
        'Bug Tracker': 'https://github.com/JeelDobariya38/pyfilehandling/issues',
        'Documentation': 'https://jeeldobariya38.github.io/pyfilehandling/',
        'Source Code': 'https://github.com/JeelDobariya38/pyfilehandling',
    },
    license='MIT',
)



import os

def create(path: str) -> None:

    """Creates a directory

    

    Args:

        path (str): The path of Directory

    """

    try:

        open(path,'x')

    except FileExistsError as _:

        print(f"FileAlreadyExist: \"{path}\" already exists")

def create_directory(path: str) -> None:

    """Creates a directory

    

    Args:

        path (str): The path of Directory

    """

    try:

        os.mkdir(path)

    except FileExistsError as _:

        print(f"DirectoryAlreadyExist: \"{path}\" already exists")

def write(path: str, data: str, mode="w") -> bool:

    """Writes data to a file.

    Args:

        path (str): The path of the file.

        data (str): The data to be written.

        mode (str, optional): The file opening mode. Defaults to "w" (write mode).

    Returns:

        bool: True if the write operation is successful, False otherwise.

    """

    with open(path, mode) as f:

        f.write(data)

        return True

def writeline(path: str, data: str, mode="w", end='\n', start="") -> bool:

    """Writes data to a file in a new line.

    Args:

        path (str): The path of the file.

        data (str): The data to be written.

        mode (str, optional): The file opening mode. Defaults to "w" (write mode).

        end (str, optional): The line ending character. Defaults to '\n' (newline).

        start (str, optional): The starting character(s) of each line. Defaults to "".

    Returns:

        bool: True if the write operation is successful, False otherwise.

    """

    with open(path, mode) as f:

        f.write(start + data + end)

        return True

def writelines(path: str, data: list, mode="w", end="\n", start="") -> bool:

    """Writes a list of data to a file, each in a new line.

    Args:

        path (str): The path of the file.

        data (list): The list of data to be written.

        mode (str, optional): The file opening mode. Defaults to "w" (write mode).

        end (str, optional): The line ending character. Defaults to '\n' (newline).

        start (str, optional): The starting character(s) of each line. Defaults to "".

    Returns:

        bool: True if the write operation is successful, False otherwise.

    """

    with open(path, mode) as f:

        for item in data:

            f.write(start + str(item) + end)

        return True

def read(path: str) -> str:

    """Reads the contents of a file.

    Args:

        path (str): The path of the file.

    Returns:

        str: The contents of the file.

    """

    with open(path, "r") as f:

        return f.read()

def readline(path: str) -> str:

    """Reads a single line from a file.

    Args:

        path (str): The path of the file.

    Returns:

        str: The first line of the file.

    """

    with open(path, "r") as f:

        return f.readline().split()[0]

def readlines(path: str) -> list:

    """Reads all lines from a file and returns them as a list.

    Args:

        path (str): The path of the file.

    Returns:

        list: A list of lines from the file.

    """

    lines = []

    with open(path, 'r') as f:

        for line in f.readlines():

            lines.append(line.split()[0])

    return lines
